@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+import gc
 import importlib
 import logging
 import os
@@ -43,6 +43,7 @@ from trainer.trainer_utils import (
     is_apex_available,
     setup_torch_training_env,
 )
+from trainer.utils.cuda_memory import cuda_meminfo, should_reduce_batch_size
 from trainer.utils.distributed import init_distributed
 
 logger = logging.getLogger("trainer")
@@ -1532,6 +1533,36 @@ class Trainer:
                 self.save_best_model()
             self.callbacks.on_epoch_end(self)
 
+    def fit_with_largest_batch_size(self, starting_batch_size=2048) -> None:
+        cuda_meminfo()
+        bs = starting_batch_size
+        while True:
+            gc.collect()
+            torch.cuda.empty_cache()
+            try:
+                gc.collect()
+                torch.cuda.empty_cache()
+                self.config.batch_size = bs
+                logger.info(" > current batch size: %i", self.config.batch_size)
+                self._fit()
+            except RuntimeError as exception:
+                if bs > 1 and should_reduce_batch_size(exception):
+                    bs //= 2
+                    gc.collect()
+                    torch.cuda.empty_cache()
+                else:
+                    raise
+            except Exception as exception: #pylint: disable=broad-except
+                # catches the torch.cuda.OutOfMemoryError
+                if bs > 1 and should_reduce_batch_size(exception):
+                    bs //= 2
+                    gc.collect()
+                    torch.cuda.empty_cache()
+                else:
+                    raise
+            else:
+                break
+
     def fit(self) -> None:
         """Where the ✨️magic✨️ happens..."""
         try:
